import {Dimensions, Platform, StatusBar} from "react-native";

const X_WIDTH = 375;
const X_HEIGHT = 812;
const XSMAX_WIDTH = 414;
const XSMAX_HEIGHT = 896;

const {width: D_WIDTH, height: D_HEIGHT} = Dimensions.get('window');

const isIPhoneX = (() => {
    if (Platform.OS === 'web') return false;

    return (
        Platform.OS === 'ios' &&
        ((D_HEIGHT === X_HEIGHT && D_WIDTH === X_WIDTH) ||
            (D_HEIGHT === X_WIDTH && D_WIDTH === X_HEIGHT)) ||
        ((D_HEIGHT === XSMAX_HEIGHT && D_WIDTH === XSMAX_WIDTH) ||
            (D_HEIGHT === XSMAX_WIDTH && D_WIDTH === XSMAX_HEIGHT))
    );
})();

const isLandscape = (() => {
    return Dimensions.get('window').width > Dimensions.get('window').height;
})();

export function getStatusBarHeight() {
    if (Platform.OS === 'ios') {
        if (isIPhoneX) return isLandscape ? 0 : 44;
    } else if (Platform.OS === 'android') {
        if (Platform.Version > 20) return StatusBar.currentHeight;
        return 0;
    }
    return isLandscape ? 0 : 20;
}

export function getBottomOffset() {
    if (Platform.OS === 'ios') {
        if (isIPhoneX) return isLandscape ? 24 : 34;
    } else if (Platform.OS === 'android') {
        if (Platform.Version > 20) return 0;
        return 0;
    }
    return isLandscape ? 0 : 20;
}

export function getScreenInset() {
    let statusBarHeight = getStatusBarHeight()
    return ({
        left: isLandscape && isIPhoneX ? 44 : 0,
        right: isLandscape && isIPhoneX ? 44 : 0,
        top: statusBarHeight,
        bottom: isIPhoneX ? (isLandscape ? 24 : 34) : 0,
    });
}

export function formatNumber(data) {
    if (data != null) {
        return data.toFixed(2);
    } else {
        return null;
    }
}

export function desensitizeMobile(mobile) {
    if (mobile && mobile.length >= 11) {
        return mobile.substr(0, 3) + " **** " + mobile.substr(mobile.length - 4, 4);
    }
    return mobile;
}

export function desensitizeBankcardNo(bankcardNo) {
    if (bankcardNo && bankcardNo.length >= 10) {
        return bankcardNo.substr(0, 4) + " **** **** " + bankcardNo.substr(bankcardNo.length - 4, 4);
    }
    return bankcardNo;
}
